from flask import Flask, render_template, request, flash, redirect, url_for
from flaskext.mysql import MySQL
from datetime import datetime
import requests
import json

app = Flask(__name__)
app.config['MYSQL_HOST'] = 'localhost'
app.config['MYSQL_USER'] = 'ben.eastwood'
app.config['MYSQL_PASSWORD'] = 'QC2BKP4E'
app.config['MYSQL_DB'] = 'beneastwood_aws'

mysql = MySQL(app, host='localhost', user='ben.eastwood', password='QC2BKP4E', db='beneastwood_aws')
mysql.init_app(app)
conn = mysql.connect()

@app.route('/')
def index():
    return render_template('index.html')

@app.route('/regions')
def regions():
    cursor = conn.cursor()
    cursor.execute('''SELECT * FROM Regions''')
    data = cursor.fetchall()
    cursor.close()
    return render_template('regions.html', data=data)

@app.route('/regionsAdd', methods = ('GET', 'POST'))
def regionsAdd(): 
    if(request.method == 'POST'):
        name = request.form['name'].lower()
        displayName = request.form['displayName']

        if not name:
            flash('Name is required!')
        elif len(name) != 2:
            flash('Name can only be two letters!')
        elif not displayName:
            flash('Display Name is required!')
        else:
            cursor = conn.cursor()
            cursor.execute('''INSERT INTO Regions (Name, DisplayName) VALUES (%s,%s)''', (name, displayName))
            conn.commit()
            cursor.close()
            return redirect(url_for('regions'))
    return render_template('regionsAdd.html')

def get_region(RegionID):
    cursor = conn.cursor()
    cursor.execute('''SELECT * FROM Regions WHERE RegionID = %s''', (RegionID))
    region = cursor.fetchone()
    return region

@app.route('/region/<int:RegionID>')
def region(RegionID):
    region = get_region(RegionID)
    return render_template('region.html', region=region)

@app.route('/<int:RegionID>/regionsEdit', methods = ('GET', 'POST'))
def regionsEdit(RegionID):
    region = get_region(RegionID)

    if(request.method == 'POST'):
        name = request.form['name']
        displayName = request.form['displayName']

        if not name:
            flash('Name is required!')
        elif len(name) != 2:
            flash('Name can only be two letters!')
        elif not displayName:
            flash('Display Name is required!')
        else:
            cursor = conn.cursor()
            cursor.execute('''UPDATE Regions SET Name = %s, DisplayName = %s WHERE RegionID = %s''', (name, displayName, RegionID))
            conn.commit()
            cursor.close()
            return redirect(url_for('regions'))
    return render_template('regionsEdit.html', region=region)

@app.route('/<int:RegionID>/regionsDelete', methods = ('POST',))
def regionsDelete(RegionID):
    region = get_region(RegionID)

    cursor = conn.cursor()
    cursor.execute('''DELETE FROM Regions WHERE RegionID = %s''', (RegionID))
    conn.commit()
    cursor.close()
    flash('"{}" was successfully deleted!'.format(region[1]))
    return redirect(url_for('regions'))

@app.route('/users')
def users():
    cursor = conn.cursor()
    cursor.execute('''SELECT * FROM Users''')
    data = cursor.fetchall()
    cursor.close()
    return render_template('users.html', data=data)

@app.route('/usersAdd', methods = ('GET', 'POST'))
def usersAdd():
    if(request.method == 'POST'):
        name = request.form['name']
        tag = request.form['tag']

        if not name:
            flash('Name is required!')
        elif not tag:
            flash('Tag is required!')
        elif len(tag) > 10:
            flash('Tag cannot be more than 10 letters.')
        else:
            createdOn = datetime.now()
            updatedOn = datetime.now()
            cursor = conn.cursor()
            cursor.execute('''INSERT INTO Users (Name, Tag, CreatedOn, UpdatedOn) VALUES (%s,%s,%s,%s)''', (name, tag, createdOn, updatedOn))
            conn.commit()
            cursor.close()
            return redirect(url_for('users'))
    return render_template('usersAdd.html')

def get_user(UserID):
    cursor = conn.cursor()
    cursor.execute('''SELECT * FROM Users WHERE UserID = %s''', (UserID))
    user = cursor.fetchone()
    return user

@app.route('/user/<int:UserID>')
def user(UserID):
    user = get_user(UserID)
    return render_template('user.html', user=user)

@app.route('/<int:UserID>/usersEdit', methods = ('GET', 'POST'))
def usersEdit(UserID):
    user = get_user(UserID)

    if(request.method == 'POST'):
        name = request.form['name']
        tag = request.form['tag']

        if not name:
            flash('Name is required!')
        elif not tag:
            flash('Tag is required!')
        elif len(tag) > 10:
            flash('Tag cannot be more than 10 letters!')
        else:
            updatedOn = datetime.now()
            cursor = conn.cursor()
            cursor.execute('''UPDATE Users SET Name = %s, Tag = %s, UpdatedOn = %s WHERE UserID = %s''', (name, tag, updatedOn, UserID))
            conn.commit()
            cursor.close()
            return redirect(url_for('users'))
    return render_template('usersEdit.html', user=user)

@app.route('/<int:UserID>/usersDelete', methods = ('POST',))
def usersDelete(UserID):
    user = get_user(UserID)

    cursor = conn.cursor()
    cursor.execute('''DELETE FROM Users WHERE UserID = %s''', (UserID))
    conn.commit()
    cursor.close()
    flash('"{}" was successfully deleted!'.format(user[1]))
    return redirect(url_for('users'))

@app.route('/elos')
def elos():
    cursor = conn.cursor()
    cursor.execute('''SELECT * FROM Elos''')
    elosData = cursor.fetchall()
    cursor.execute('''SELECT * FROM Users''')
    usersData = cursor.fetchall()
    cursor.execute('''SELECT * FROM Regions''')
    regionsData = cursor.fetchall()
    cursor.close()
    return render_template('elos.html', elosData=elosData, usersData=usersData, regionsData=regionsData)

@app.route('/elosCheck')
def elosCheck():
    cursor = conn.cursor()
    cursor.execute('''SELECT * FROM Users''')
    data = cursor.fetchall()
    cursor.close()
    return render_template('elosCheck.html', data=data)

@app.route('/elo/<int:UserID>')
def elo(UserID):
    user = get_user(UserID)
    cursor = conn.cursor()
    cursor.execute('''SELECT * FROM Regions''')
    data = cursor.fetchall()
    cursor.close()
    return render_template('elo.html', user=user, data=data)

@app.route('/<int:UserID>/<int:RegionID>/eloFetch', methods = ('GET', 'POST'))
def eloFetch(UserID, RegionID):
    user = get_user(UserID)
    region = get_region(RegionID)
    api_url = "https://api.henrikdev.xyz/valorant/v1/mmr/" + region[1] + "/" + user[1] + "/" + user[2]

    if(request.method == 'POST'):
        rank = request.form['rank']
        elo = request.form.get("elo")
        overallElo = request.form.get("overallElo")
        createdOn = datetime.now()
        updatedOn = datetime.now()
        cursor = conn.cursor()
        cursor.execute('''INSERT INTO Elos (UserID, RegionID, Rank, RatingInRank, OverallRating, CreatedOn, UpdatedOn) VALUES (%s,%s,%s,%s,%s,%s,%s)''', (user[0], region[0], rank, elo, overallElo, createdOn, updatedOn))
        conn.commit()
        cursor.close()
        return redirect(url_for('elos'))
    return render_template('eloFetch.html', user=user, region=region, api_url=api_url, checkElo="True")

@app.route('/<int:EloID>/elosUpdate', methods = ('GET', 'POST'))
def elosUpdate(EloID):
    elo = get_elo(EloID)
    user = get_user(elo[1])
    region = get_region(elo[2])
    api_url = "https://api.henrikdev.xyz/valorant/v1/mmr/" + region[1] + "/" + user[1] + "/" + user[2]

    if(request.method == 'POST'):
        rank = request.form['rank']
        eloText = request.form.get("elo")
        overallElo = request.form.get("overallElo")
        updatedOn = datetime.now()
        cursor = conn.cursor()
        cursor.execute('''UPDATE Elos SET Rank = %s, RatingInRank = %s, OverallRating = %s, UpdatedOn = %s WHERE EloID = %s''', (rank, eloText, overallElo, updatedOn, elo[0]))
        conn.commit()
        cursor.close()
        return redirect(url_for('elos'))
    return render_template('elosUpdate.html', elo=elo, user=user, region=region, api_url=api_url, checkElo="True")

def get_elo(EloID):
    cursor = conn.cursor()
    cursor.execute('''SELECT * FROM Elos WHERE EloID = %s''', (EloID))
    user = cursor.fetchone()
    return user

if __name__ == '__main__':
        print("== Running in debug mode ==")
        app.secret_key = "secret key"
        app.run(host='ysjcs.net', port=5007, debug=True)